ES.obj object containing the result.
getPLM.es(abatch, trt1, trt2, covariates=NULL, dep.grp=NULL, sub.gn=NULL, bg.norm=TRUE)AffyBatch object containing the data of interest. trt1 / trt2 vector pair defines a comparison of interest. trt1 / trt2 vector pair defines a comparison of interest. data.frame object representing covariate differences, if any, among the comparisons defined by trt1 / trt2 vector pairs. This data.frame should have a named column for each covariate to be considered in the meta-analysis, regardless of whether the covariate takes on multiple values in the study represented by the abatch argument. This data.frame must have a row for each comparison of interest, as defined by the trt1 / trt2 vector pairs. Elements of this data.frame should be coded numerically. ES.obj
Bolstad B. M. (2004), Low-level Analysis of High-density Oligonucleotide Array Data: Background, Normalization and Summarization, PhD dissertation, U.C. Berkeley.
Hu P., Greenwood C.M.T., and Beyene J. (2006), Integrative Analysis of Gene Expression Data Including an Assessment of Pathway Enrichment for Predicting Prostate Cancer, Cancer Informatics 2006:2 289-300.
Stevens J.R. and Nicholas G. (2009), metahdep: Meta-analysis of hierarchically dependent gene expression studies, Bioinformatics, 25(19):2619-2620.
See also the metahdep package vignette.
###
### See the metahdep package vignette for a full example
###
Run the code above in your browser using DataLab